# How to connect your radar to TI software and use our code
## Introduction
This document intends to show you how to use our repository with the TI radar and associated software ([mmWave studio](http://software-dl.ti.com/ra-processors/esd/MMWAVE-STUDIO/latest/index_FDS.html)). While this codebase can handle all signal processing, tracking and clustering after acquiring ADC data as it provides, it still relies on the mmWave studio to connect, configure and extract data, so this document will explain to you the limitation of this codebase to handle hardware, and point you to the useful resources provided by TI. 

## Steps to gather data
[mmWave studio](http://software-dl.ti.com/ra-processors/esd/MMWAVE-STUDIO/latest/index_FDS.html) is used to connect your radar to the PC, configure the ADC output format, chirp and frame design, etc. The mmWave studio requires [mmWave SDK](http://software-dl.ti.com/ra-processors/esd/MMWAVE-SDK/lts-latest/index_FDS.html). Follow the provided link and read the [User Guide](http://software-dl.ti.com/ra-processors/esd/MMWAVE-STUDIO/latest/exports/mmwave_studio_user_guide.pdf) to get a grasp of how to use this software. Here are few tips we learned while working with this software:

1. **Connection**: Connecting your radar to the software is rather tricky sometimes in that there are multiple firmware version. Generally, the firmware binary from the mmWave Studio installation should work, but if not, download the [firmware package](http://www.ti.com/tool/MMWAVE-DFP) and try them out. You have to make sure there is no warning from connection.
2. **Chirp design**: Chirp configuration depends on your application. There are three components related to this topic: profileConfig (how each chirp will look like), chirpConfig (which chirp use what profile and firing sequence) and frameConfig (how long each frame will be and how many frames you want to fire). Usually the TI example code has much more configuration structs such as cfarConfig, ekfConfig, etc, but only the aforementioned three structs are directly related to hardware setup, the rest of which are no more than parameters in software only. Consult the [SDK User Guide](http://software-dl.ti.com/ra-processors/esd/MMWAVE-SDK/lts-latest/exports/mmwave_sdk_user_guide.pdf) for the meaniing of each parameter.
3. **Gathering data**: After the first two steps are done, the rest is to gather data. Again, TI's document is a good place to start. However, to work with our software, you need to run the [dataloader](https://github.com/PreSenseRadar/OpenRadar/mmwave/dataloader) or has the dataloader built-in, just as our demo. Essentially it will sniff the data packets from Ethernet connection and automatically send the ADC data to our DSP modules. Our module provides real-time streaming and offline processing capability of ADC data from DCA1000 and offline processing only for TSW1400 ADC data. Due to the software limitation, you have to manually remove the binary data file gathered by TI to free up your disk space.
4. **Automation**: Of course you can click through everything painfully and conduct your research on radar, but there is much more efficient way to streamline this process with Lua scripts provided by TI. All the 3 steps aboe can be automated as soon as the mmWave studio software launches and you load the Lua script. Consult the given Lua scrips from mmWave studio installation, or you can use the two [scripts](https://github.com/PreSenseRadar/OpenRadar/scripts) we provided as reference.

## Note
The purpose of this repo is to help you understand radar signal processing and with faster prototyping and evaluation of TI radar, and current solution is sufficent enough to provide such capability. Therefore, operating witout mmWave studio is not in our forseeable develop plan. We would prefer to provide more new DSP and machine learning algorithms and demos than to provide an engineering solution to "hack" the board.